/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Gnu General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Gnu General Public License for more details.
 *
 * You should have received a copy of the Gnu General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.antsim;

import java.util.*;
import anthill.util.*;

/**
 * The <CODE>Stats</CODE> interface enables programmers to collect 
 * information about events occurring during a simulation. In particular, 
 * this class may be used to count the occurrence of events. Each event
 * is identified by a string name chosen by the programmer and is associated 
 * to a counter. The value of the counter may be incremented by one by 
 * invoking method <CODE>inc()</CODE>; the same value may be read by invoking 
 * method <CODE>get()</CODE>. Additionally, a counter may be incremented by a 
 * arbitrary value using method <CODE>add()</CODE>.
 *
 * @author Alberto Montresor
 * @version $REVISION$
 */
public interface Stats
extends Clearable
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Increment by 1 the value of the counter identified by <CODE>name</CODE>.
   *
   */
  public void inc(String name);

  /**
   * Increment the value of the counter identified by <CODE>name</CODE> by 
   * value <CODE>addend</CODE>. 
   *
   */
  public void add(String name, float addend);

  /**
   *  Return the value of the counter identified  by <CODE>name</CODE>
   */
  public float get(String name);

  
} // END Stats

