/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Gnu General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Gnu General Public License for more details.
 *
 * You should have received a copy of the Gnu General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package gnutant;

import java.util.*;
import java.security.*;

import anthill.*;
import anthill.factory.*;
import anthill.util.*;

/**
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class GnutantFactory
implements AntFactory
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Static fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Message digest generator used to produce hash values for strings
   */
  static private MessageDigest digest;
  
  static {
    try {
      digest = MessageDigest.getInstance("SHA");
    } catch (NoSuchAlgorithmException e) {
      Util.panic(e);
    }
  }
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  
   */
  public GnutantFactory()
  {
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *   Returns a set of ants for a query. Each ant will take care of
   *   the research of a distinct token of the query string. 
   */
  public Ant[] getAnts(Object request)
  {
    // FIXME Add opportune checks and exception
    String query = (String) request;
    
    /* Divide the string into fragments separated by spaces */
    StringTokenizer tokenizer = new StringTokenizer(query);
    
    /* We create a list of ants that will take care of this query */
    ArrayList list = new ArrayList();
    
    /* Create an ant for each of the fragements composing the segment */
    while (tokenizer.hasMoreTokens()) {

      /* Compute the digest of each of the fragment*/
      String fragment = tokenizer.nextToken();
      digest.reset();
      digest.update(fragment.getBytes()); // FIXME Should we consider character encoding
      byte[] hash = digest.digest();
          
      Gnutant ant = new Gnutant(query, hash);
      list.add(ant);
    }
    Ant[] ants = new Ant[list.size()];
    for (int i=0; i < ants.length; i++)
      ants[i] = (Ant) list.get(i);
    return ants;
  }
  
} // END GnutantFactory


